@@ -3,6 +3,7 @@ and returns the nearest plum tree to that location"""
 
 import json
 import configparser
+import logging
 import os
 from dataclasses import dataclass
 from time import time
@@ -339,6 +340,10 @@ def find_closest_plum(input_address: str, config):
     performance_log = config['Settings'].getboolean('performancelog')
     use_SQL = config['Settings'].getboolean('usesql')
 
+    global data_dir
+    data_dir = os.path.join(os.path.dirname(__file__), 'data')
+    logging.debug(f'Data dir: {data_dir}')
+
     geocode_set = False
 
     # only allow up to 25 trees
@@ -348,6 +353,7 @@ def find_closest_plum(input_address: str, config):
     if performance_log:
         start_time = time()
 
+    input_address = input_address.replace('.', '')
     user_address = Address(input_address)
 
     SF_streets = load_SF_streets()
@@ -467,12 +473,14 @@ def return_tree(closest_tree, input_address: str):
     # return the closest tree
     address = closest_tree['qAddress'][0]
     species = closest_tree['qSpecies'][0]
+    scientific_name, common_name = species.split(' :: ')
     distance = closest_tree['street_distance'][0]
 
-    response = """Closest tree to {}:
-Species: {}
-Address: {}
-Distance: {}m""".format(input_address, species, address, distance)
+    response = f"""Closest tree to {input_address.title()}:
+Sc. Name: {scientific_name.title()}
+Name: {common_name.title()}
+Address: {address}
+Distance: {distance}m"""
     return response
 
 
